summaryrefslogtreecommitdiff
path: root/gtk/gtkimcontextsimple.c
diff options
context:
space:
mode:
authorTakao Fujiwara <tfujiwar@redhat.com>2014-09-08 12:41:48 +0900
committerMatthias Clasen <mclasen@redhat.com>2014-09-10 21:30:46 -0400
commit9f1724b3556bb09cc39b4e4a708620f02413f9a4 (patch)
tree3f4cbe6c9dedcf628d22186ccb233c765688128e /gtk/gtkimcontextsimple.c
parenta13c41137e454cf7a7a2a572e9483fa4a827e542 (diff)
downloadgtk+-9f1724b3556bb09cc39b4e4a708620f02413f9a4.tar.gz
Update gtk_compose_seqs_compact[] table for French layout bepo variant.
fr(bepo) XKB keymap sends dead_stroke with AltGr+l keys and gtk-im-simple-context should send '/' with dead_stroke+dead_stroke keys but gtkimcontextsimpleseqs.h was not sorted in the descending order and failed to get dead_stroke. Also need to add dead_currency for Shift+AltGr+e and dead_belowcomma for Shift+AltGr+Cedilla. https://bugzilla.gnome.org/show_bug.cgi?id=736250
Diffstat (limited to 'gtk/gtkimcontextsimple.c')
-rw-r--r--gtk/gtkimcontextsimple.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gtk/gtkimcontextsimple.c b/gtk/gtkimcontextsimple.c
index 41ab8c29a9..d5adf33db2 100644
--- a/gtk/gtkimcontextsimple.c
+++ b/gtk/gtkimcontextsimple.c
@@ -72,7 +72,7 @@ struct _GtkComposeTableCompact
*/
#include "gtkimcontextsimpleseqs.h"
/* From the values below, the value 24 means the number of different first keysyms
* that exist in the Compose file (from Xorg). When running compose-parse.py without
* parameters, you get the count that you can put here. Needed when updating the
* gtkimcontextsimpleseqs.h header file (contains the compose sequences).
@@ -80,7 +80,7 @@ struct _GtkComposeTableCompact
static const GtkComposeTableCompact gtk_compose_table_compact = {
gtk_compose_seqs_compact,
5,
- 25,
+ 30,
6
};
@@ -72,7 +72,7 @@ struct _GtkComposeTableCompact
*/
#include "gtkimcontextsimpleseqs.h"
-/* From the values below, the value 24 means the number of different first keysyms
+/* From the values below, the value 30 means the number of different first keysyms
* that exist in the Compose file (from Xorg). When running compose-parse.py without
* parameters, you get the count that you can put here. Needed when updating the